<?php

App::uses('EvSlideShowAppController', 'EvSlideShow.Controller');

/**
 * SlideshowSlides Controller
 *
 */
class SlidesController extends EvSlideShowAppController {

	public $max_depth = 1;


/**
 * @return void
 * @see Controller::beforeFilter()
 */
	public function beforeFilter() {

		parent::beforeFilter();

		$this->Auth->allow(array(
			'fetch_slideshow'
		));

		return;

	}


/**
 * Used by the SlideshowHelper's requestAction to retrieve slides.
 * 
 * @return array
 */ 
	public function fetch_slideshow() {

		return $this->Slide->getSlides();

	}


/**
 * @return array
 */
	protected function _adminIndexColumns() {

		$columns = array(
			'Slide.name' => array(
				'type' => 'string',
				'null' => false,
				'default' => null,
				'length' => (int) 200,
				'collate' => 'utf8_general_ci',
				'charset' => 'utf8',
				'label' => 'Name'
			),
		);

		return $columns;

	}


/**
 * @return array
 */
	protected function _adminFormFields() {

		$fields = parent::_adminFormFields();

		$configFields = Configure::read('EvSlideShow.fields');

		foreach ($configFields as $key => $value) {

			if ($key == 'Slide.extra') {

				foreach ($value as $extra_key => &$extra_value) {

					if (isset($extra_value['validate'])) {

						unset($extra_value['validate']);
					}

					$configFields['Slide.extra_' . $extra_key] = $extra_value;

				}

			} else {

				if (isset($value['validate'])) {

					unset($configFields[$key]['validate']);
				}

			}

			if (empty($value) || $key === 'Slide.extra') {
				unset($configFields[$key]);
				unset($fields[$key]);
			}

		}

		$fields = ArrayUtil::addAfter($fields, 'Slide.name', $configFields);

		unset($fields['Slide.orderno']);

		return $fields;

	}


/**
 * Defines which actions are available to each row of the admin_index table results.
 * 
 * @return array
 */
	protected function _adminIndexActions() {

		return array(
			'Edit',
			'Delete',
		);

	}


	protected function _processValidation() {
		
		// Add the custom validation if set
		$configFields = Configure::read('EvSlideShow.fields');

		if (empty($configFields)) {
			throw new exception("Slide show fields config is empty");
		}

		foreach ($configFields as $key => $value) {

			if ($key == 'Slide.extra') {

				foreach ($value as $extra_key => $extra_value) {

					if (!empty($extra_value['validate'])) {

						$this->Slide->validate['extra_' . $extra_key] = array();

						foreach ($extra_value['validate'] as $rule => $rule_data) {

							$this->Slide->validate['extra_' . $extra_key][$rule] = $rule_data;
						}
					}
				}

			} else {

				if (!empty($value['validate'])) {

					$column = preg_replace('|\w+\.|i', '', $key);

					foreach ($value['validate'] as $rule => $rule_data) {

						$this->Slide->validate[$column][$rule] = $rule_data;

					}
				}

			}

		}

		return;

	}


	public function admin_edit($id = null) {

		$this->_processValidation();

		return parent::admin_edit($id);

	}

}